import { createRouter, createWebHashHistory } from "vue-router"

const routes = [
  {
    name: "notFound",
    path: "/:path(.*)+",
    redirect: {
      name: "home",
    },
  },
  {
    name: "login",
    path: "/login",
    component: () => import("./view/login"),
    meta: {
      title: "登录",
    },
  },
  {
    path: "/",
    redirect: "/home",
    name: "layout",
    component: () => import("./layout"),
    children: [
      {
        path: "/home",
        name: "home",
        component: () => import("./view/home"),
        meta: {
          title: "房源管理",
        },
      },
      {
        path: "/house/add",
        name: "house.add",
        component: () => import("./view/addhouse"),
        meta: {
          title: "房源录入",
        },
      },
      {
        name: "user",
        path: "/user",
        component: () => import("./view/user"),
        meta: {
          title: "我的",
        },
      },
    ],
  },
  {
    path: "/secondhand/detail",
    name: "secondhand.detail",
    component: () => import("./view/secondhand/detail"),
    meta: {
      title: "二手房详情",
    },
  },
  {
    path: "/renting/detail",
    name: "renting.detail",
    component: () => import("./view/renting/detail"),
    meta: {
      title: "租房详情",
    },
  },

  {
    path: "/house/close",
    name: "house.close",
    component: () => import("./view/closehouse"),
    meta: {
      title: "关闭房源",
    },
  },
  {
    path: "/followup",
    name: "followup",
    component: () => import("./view/followup"),
    meta: {
      title: "跟进房源",
    },
  },
  {
    path: "/look",
    name: "look",
    component: () => import("./view/look"),
    meta: {
      title: "添加空看",
    },
  },

  {
    path: "/secondhand/edit",
    name: "secondhand.edit",
    component: () => import("./view/secondhand/edithouse"),
    meta: {
      title: "编辑房源",
    },
  },
  {
    path: "/renting/edit",
    name: "renting.edit",
    component: () => import("./view/renting/edithouse"),
    meta: {
      title: "编辑房源",
    },
  },
  {
    path: "/resc",
    name: "resc",
    component: () => import("./view/resc"),
    meta: {
      title: "实勘上传",
    },
  },
  {
    path: "/room-auth",
    name: "room.auth",
    component: () => import("./view/room-auth"),
    meta: {
      title: "委托书新增",
    },
  },
  {
    path: "/room-key",
    name: "room.key",
    component: () => import("./view/room-key"),
    meta: {
      title: "添加钥匙",
    },
  },
]

const router = createRouter({
  routes,
  history: createWebHashHistory(),
})

// const isAuthenticated= false

router.beforeEach((to, from, next) => {
  const title = to.meta && to.meta.title
  if (title) {
    document.title = title
  }

  next()
})

export { router }
