import {
  reactive,
  ref
} from "vue"
import request from "@/utils/request"
import {
  showDanger
} from "@/utils"

export default () => {
  const loading = ref(false)
  const list = ref([])
  const page = reactive({})
  const detail = reactive({})
  const rentRole = reactive({})
  const rentKeyBox = reactive({})
  const getList = (data) => {
    loading.value = true
    request({
        loadingId: "renting.list",
        url: "/rent/list",
        data: {
          pageNo: 1,
          pageSize: 10,
          ...data,
        },
      })
      .then((res) => {
        const {
          pageNo,
          pageSize,
          endRow,
          result
        } = res || {}
        Object.assign(page, {
          pageNo,
          pageSize,
          endRow,
        })
        list.value = pageNo <= 1 ? result : list.value.concat(list.value)
        loading.value = false
      })
      .catch((e) => {
        console.error(e)
        loading.value = false
      })
  }

  const getDetail = (data) => {
    // loading.value = true
    request({
        loadingId: "rent.view",
        url: "/rent/view",
        params: {
          id: data,
        },
      })
      .then((res) => {
        console.log(res, "res")

        Object.assign(detail, res)
      })
      .catch((e) => {
        console.error(e)
        // loading.value = false
        showDanger("获取详情失败")
      })
  }

  // 角色人信息
  const getRole = (data) => {
    request({
        loadingId: "rent.role.view",
        url: "/rent/role/view",
        params: {
          roomId: data,
        },
      })
      .then((res) => {
        Object.assign(rentRole, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger("获取角色人失败")
      })
  }

  // 钥匙信息
  const getKey = (data) => {
    request({
        loadingId: "rent.key.view",
        url: "/rent/key/view",
        params: {
          roomId: data,
        },
      })
      .then((res) => {
        Object.assign(rentKeyBox, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger("获取钥匙失败")
      })
  }

  // 业主电话
  const addOwnerTel = (params) => {
    return request({
      url: "/rent/own-tel/add",
      params,
      toast: "请稍候...",
    }).then(() => {
      const ownerTel = detail.roomInfo.ownerTel || ""
      detail.roomInfo.ownerTel = ownerTel
        .split(",")
        .filter(Boolean)
        .concat(params.newOwnerTel)
        .join(",")
      return
    })
  }

  // 获取楼栋详情
  const getBuilding = (estateId) => {
    return request({
      url: "/room/building",
      params: {
        estateId,
      },
    })
  }

  // 房源下架
  const closeHouse = (data) => {
    return request({
      url: "/rent/close",
      params: {
        estateId: data.estateId,
      },
      data,
      toast: "请稍候...",
    }).then(() => {
      return
    })
  }

  // 房源编辑
  const houseEdit = (data) => {
    return request({
      url: "/rent/save",
      data,
      toast: "请稍候...",
    })
  }

  // 实勘列表
  const getRescList = (roomId) => {
    return request({
      url: "/rent/resc/list",
      params: {
        roomId
      },
      loadingId: "room.resc.list",
    })
  }

  // 设置封面
  const setRescCover = (rescId) => {
    return request({
      url: "/rent/resc/cover",
      params: {
        id: rescId
      },
      toast: "请稍候...",
    })
  }

  // 保存
  const saveResc = (data, roomId) => {
    return request({
      url: "/rent/resc/save",
      headers: {
        "Content-Type": "application/json",
      },
      params: {
        roomId
      },
      data,
      toast: "请稍候...",
    })
  }

  // 删除
  const deleteResc = ({
    roomId,
    rescId,
    rescType
  }) => {
    return request({
      url: "/rent/resc/delete",
      params: {
        roomId,
        rescId,
        rescType
      },
      toast: "请稍候...",
    })
  }

  // 查看业务房源数
  const countOwnerTel = (ownerTel) => {
    return request({
      url: '/rent/owner-tel/count',
      params: {
        ownerTel
      },
      toast: '请稍候...',
    })
  }

  // 新增房源
  const addHouse = (params, data) => {
    return request({
      url: '/rent/add',
      params,
      data,
      toast: '请稍候...',
    })
  }

  return {
    list,
    page,
    getList,
    detail,
    getDetail,
    loading,
    getRole,
    rentRole,
    getKey,
    rentKeyBox,
    addOwnerTel,
    getBuilding,
    closeHouse,
    houseEdit,
    getRescList,
    setRescCover,
    saveResc,
    deleteResc,
    countOwnerTel,
    addHouse,
  }
}